@@ -1,5 +1,4 @@
-/* $Id: kmo_illumination_flat.c,v 1.1 2013/10/21 13:44:55 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013/10/21 13:44:55 $
- * $Revision: 1.1 $
- * $Name:  $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -195,7 +187,7 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
                         "Alternative to kmo_illumination based on flatfield frames.",
                         kmo_illumination_flat_description,
                         "Alex Agudo Berbel",
-                        "kmos-spark@mpe.mpg.de",
+                        "usd-help@eso.org",
                         kmos_get_license(),
                         kmo_illumination_flat_create,
                         kmo_illumination_flat_exec,
@@ -289,11 +281,11 @@ static int kmo_illumination_flat_create(cpl_plugin *plugin)
     cpl_parameterlist_append(recipe->parameters, p);
 
     // add parameters for band-definition
-    kmo_band_pars_create(recipe->parameters,
+    kmos_band_pars_create(recipe->parameters,
                          "kmos.kmo_illumination_flat");
 
     // add parameters for combining
-    return kmo_combine_pars_create(recipe->parameters,
+    return kmos_combine_pars_create(recipe->parameters,
                                    "kmos.kmo_illumination_flat",
                                    DEF_REJ_METHOD,
                                    FALSE);
@@ -532,10 +524,10 @@ static int kmo_illumination_flat(cpl_parameterlist *parlist, cpl_frameset *frame
                        CPL_ERROR_ILLEGAL_INPUT,
                        "suppress_extension must be TRUE or FALSE!");
 
-        kmo_band_pars_load(parlist, "kmos.kmo_illumination_flat");
+        kmos_band_pars_load(parlist, "kmos.kmo_illumination_flat");
 
         KMO_TRY_EXIT_IF_ERROR(
-            kmo_combine_pars_load(parlist, "kmos.kmo_illumination_flat",
+            kmos_combine_pars_load(parlist, "kmos.kmo_illumination_flat",
                                   &cmethod, &cpos_rej, &cneg_rej,
                                   &citer, &cmin, &cmax, FALSE));
         cpl_msg_info("", "-------------------------------------------");
@@ -915,12 +907,6 @@ static int kmo_illumination_flat(cpl_parameterlist *parlist, cpl_frameset *frame
             //
             print_warning_once_reconstruct = FALSE;
 
-            char *tmp_band_method = getenv("KMO_BAND_METHOD");
-            int band_method = 0;
-            if (tmp_band_method != NULL) {
-                band_method = atoi(tmp_band_method);
-            }
-
             // ESO INS FILTi ID
             KMO_TRY_EXIT_IF_NULL(
                 keyword = cpl_sprintf("%s%d%s", IFU_FILTID_PREFIX, det_nr,
@@ -932,8 +918,7 @@ static int kmo_illumination_flat(cpl_parameterlist *parlist, cpl_frameset *frame
             KMO_TRY_EXIT_IF_NULL(
                 band_table = kmo_dfs_load_table(frameset, WAVE_BAND, 1, 0));
             KMO_TRY_EXIT_IF_ERROR(
-                kmclipm_setup_grid_band_lcal(&gd, lcal, filter_id, band_method,
-                                             band_table));
+                kmclipm_setup_grid_band_lcal(&gd, filter_id, band_table));
             cpl_table_delete(band_table); band_table = NULL;
 
             cpl_msg_info("","Reconstructing cubes...");
@@ -1257,6 +1242,17 @@ static int kmo_illumination_flat(cpl_parameterlist *parlist, cpl_frameset *frame
                                      main_header, parlist, cpl_func));
 
         for (i = 0; i < nr_devices * KMOS_IFUS_PER_DETECTOR; i++) {
+            cpl_propertylist_erase(stored_sub_headers[i], CRPIX3);
+            cpl_propertylist_erase(stored_sub_headers[i], CRVAL3);
+            cpl_propertylist_erase(stored_sub_headers[i], CDELT3);
+            cpl_propertylist_erase(stored_sub_headers[i], CTYPE3);
+            cpl_propertylist_erase(stored_sub_headers[i], CUNIT3);
+            cpl_propertylist_erase(stored_sub_headers[i], CD1_3);
+            cpl_propertylist_erase(stored_sub_headers[i], CD2_3);
+            cpl_propertylist_erase(stored_sub_headers[i], CD3_3);
+            cpl_propertylist_erase(stored_sub_headers[i], CD3_2);
+            cpl_propertylist_erase(stored_sub_headers[i], CD3_1);
+
             KMO_TRY_EXIT_IF_ERROR(
                 kmo_dfs_save_image(stored_data_images[i], ILLUM_CORR_FLAT, fn_suffix,
                                    stored_sub_headers[i], 0./0.));
