@@ -10,9 +10,9 @@ if [ $# -eq 0 ]; then
     echo "${bb}-------------------------------------------------------------------${nn}"
     echo "${bb}Run the KMOS pipeline on a whole set of calibration files."
     echo " "
-    echo "This includes kmo_dark for all filters and angles"
-    echo "              kmo_flat"
-    echo "              kmo_wave_cal${nn}"
+    echo "This includes kmos_dark for all filters and angles"
+    echo "              kmos_flat"
+    echo "              kmos_wave_cal${nn}"
     echo " "
     echo "${bb}IMPORTANT:${nn} Files can be searched as well in folders from +/- 1 day!"
     echo "           (if toplevel directories are e.g. named YYYY-MM-DD)"
